/*
    qtparted - a frontend to libparted for manipulating disk partitions
    Copyright (C) 2002-2003 Vanni Brutto

    Vanni Brutto <zanac (-at-) libero dot it>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <qpixmap.h>
#include <qmessagebox.h>
#include <qstrlist.h>
#include <sys/param.h>  // MAXPATHLEN
#include "qp_drivelist.h"
#include "qp_libparted.h"
#include "qp_common.h"
#include "xpm/tool_disk.xpm"

QP_DriveList::QP_DriveList(QWidget *parent, const char *name)
    :QListView(parent, name) {

    setAllColumnsShowFocus(true);
    addColumn(tr("Device"));
    setSelectionMode(Single);

//    buildView();

    connect(this, SIGNAL(selectionChanged(QListViewItem *)),
            this, SLOT(slotListSelected(QListViewItem *)));

    /*---prevent from memory leak: when list are cleared destroy QP_Device object!---*/
    lstDevices.setAutoDelete(true);
}

QP_DriveList::~QP_DriveList() { 
}

void QP_DriveList::buildView() {
    /*---make the "root" of the listview---*/
    QListViewItem *ideRoot = new QListViewItem(this, tr("Disks"));

    /*---get a list of all available devices---*/
    QStrList lstdrives = QP_LibParted::device_probe();
    if (lstdrives.count() == 0) {
        QMessageBox::information(this, "QTParted",
                QString(tr("No device found. Maybe you're not using root user?")));
    }

    /*---clear old lstDevices list---*/
    lstDevices.clear();

    /*---make the group menu---*/
    _agDevices = new QActionGroup(this, 0);
    _agDevices->setExclusive(true);
    connect(_agDevices, SIGNAL(selected(QAction *)), this, SLOT(slotActionSelected(QAction *)));

    /*---add every device found---*/
    for (uint i = 0; i < lstdrives.count(); ++i) {
        QString st = lstdrives.at(i);

        /*---if devfs is enable convert the string name---*/
        if (flagDevfsEnabled) {
            char newstr[MAXPATHLEN];
            QP_LibParted::convertDevfsNameToShortName(st.latin1(), newstr, sizeof(newstr));
            st = QString(newstr);
        }
        
        /*---add to the listview---*/
        QListViewItem *item = addDevice(st, ideRoot);

        /*---add to the group menu---*/
    	QAction *actDisk = new QAction(st, QIconSet(), QString::null/*accell*/, 0, _agDevices, 0, _agDevices->isExclusive());

        QP_Device *device = new QP_Device();
        device->action = actDisk;
        device->listitem = item;
        lstDevices.append(device);
    }

    if (ideRoot->childCount())
        ideRoot->setOpen( true );
    else
        delete ideRoot;
}

QListViewItem *QP_DriveList::addDevice(QString dev, QListViewItem *parent) {
    QListViewItem *item = new QListViewItem(parent, dev);
    item->setPixmap(0, QPixmap(tool_disk));

    return item;
}

QActionGroup *QP_DriveList::agDevices() {
    return _agDevices;
}

void QP_DriveList::slotListSelected(QListViewItem *item) {
    /*---if the item selected is not the root---*/
    if (!item->childCount()) {
        /*---get the device name (ex. /dev/hda)---*/
        QString name = item->text(0);

        /*---scan for every menu in the group---*/
        QP_Device *p;
        for (p = (QP_Device *)lstDevices.first(); p; p = (QP_Device *)lstDevices.next()) {
            /*---the name match, so select it!---*/
            if (p->action->text().compare(name) == 0)
                p->action->setOn(true);
        }
        emit selected(name);
    }
}

void QP_DriveList::slotActionSelected(QAction *action) {
    /*---get the device name (ex. /dev/hda)---*/
    QString name = action->text();

    /*---scan for every menu in the group---*/
    QP_Device *p;
    for (p = (QP_Device *)lstDevices.first(); p; p = (QP_Device *)lstDevices.next()) {
        /*---the name match, so select it!---*/
        if (p->listitem->text(0).compare(name) == 0)
            setSelected (p->listitem, true);
    }
}
