/*
    qtparted - a frontend to libparted for manipulating disk partitions
    Copyright (C) 2002-2003 Vanni Brutto

    Vanni Brutto <zanac (-at-) libero dot it>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* About QP_LibParted class:
 *
 * This is a the wrapper to the libparted. Just use this class instead of call
 * native method!
 */

#ifndef QT_LIBPARTED_H
#define QT_LIBPARTED_H

#include <qptrlist.h>
#include <qwidget.h>
#include <qstrlist.h>
#include <parted/parted.h>
#include "qtparted.h"
#include "qp_filesystem.h"

class QP_PartWidget;
class QP_ListViewItem;
class QP_LibParted;

QString MB2String(float);

class QP_PartInfo : public QObject {
friend class QP_LibParted;
    Q_OBJECT
public:
    QP_FileSystemSpec *fsspec;
    QTParted::Type type;
    int num;
    PedSector t_start;
    PedSector t_end;
    PedSector start;
    PedSector end;
    PedSector min_size;
    QP_PartWidget *partwidget;
    QP_ListViewItem *listviewitem;
    int  width;
    QString device;
    float mb_t_start();
    float mb_t_end();
    float mb_start();
    float mb_end();
    float mb_min_size();
    QString partname();
    QString label;
    bool isFree();                        /*---return true if the filesystem is free space  ---*/
    bool isUnknow();                      /*---return true if the filesystem is unknow space---*/
    bool isActive();                      /*---return true if the partition is active       ---*/
    bool canBeActive();                   /*---return true if the partition can be actived  ---*/
    bool setActive(bool);                 /*---change the active status                     ---*/
    bool resize(PedSector, PedSector);    /*---resize the partition (start, end sectors     ---*/
    bool move(PedSector, PedSector);      /*---move the partition (start, end sectors       ---*/
    bool partition_is_busy();             /*---test if the partition is busy (ie mounted)   ---*/
    bool set_system(QP_FileSystemSpec *); /*---change the systemid of the partition         ---*/
    bool fswrap();
    PedSector wrap_min_size();
    QString message();

private:
    QP_FileSystemSpec *_free;     /*---internal pointer to the "free" flag          ---*/
    QP_FileSystemSpec *_unknow;   /*---internal pointer to the "unknow" flag        ---*/
    bool _active;                 /*---flag active                                  ---*/
    bool _canBeActive;            /*---flag can be active                           ---*/
    QP_LibParted *_libparted;
};

class qtp_DriveInfo {
public:
  QString device;
  QString model;
  QString mb_capacity;
  QString length_sectors;
};

class QP_LibParted : public QObject
{
friend class QP_PartInfo;
    Q_OBJECT
public:
    QP_LibParted(QString device);
    ~QP_LibParted();
    void scan_partitions();
    static QStrList device_probe();
    static qtp_DriveInfo device_info(QString);
    static int convertDevfsNameToShortName(const char *szDevfs, char *szShort, int nMaxShort);
    void get_filesystem(QP_FileSystem *);
    QPtrList<QP_PartInfo> partlist;
    QPtrList<QP_PartInfo> logilist;
    void partition_get_flags(QP_PartInfo *, PedPartition *); /*---get active flag---*/
    bool partition_set_flag_active(QP_PartInfo *, bool);     /*---set active flag---*/
    QP_PartInfo *partActive();                               /*---return the active partition---*/
    int grow_over_small_freespace (PedGeometry* geom, PedDisk* disk);
    PedSector get_right_bound (PedSector sector, PedDisk* disk);
    PedSector get_left_bound (PedSector sector, PedDisk* disk);
    bool set_system(QP_PartInfo *, QP_FileSystemSpec *);
    int mkpart(PedSector start, PedSector end, PedPartitionType, QP_FSWrap *, QString);
    int mkpartfs(QTParted::Type, QP_FileSystemSpec *, PedSector, PedSector, QString);
    int rm(int);
    bool partition_is_busy(int); /*---test if the partition is busy (ie mounted)---*/
    float mb_hdsize();
    bool has_extended;
    QP_FileSystem *filesystem; /*---a class with all feature of filesystems   ---*/
    void setFastScan(bool);    /*---make the scan of filesystems fast!        ---*/
    bool move(QP_PartInfo *, PedSector, PedSector);
    bool resize(QP_PartInfo *, PedSector, PedSector);
    bool set_geometry(QP_PartInfo *, PedSector, PedSector);
    QString message();
    void emitSigTimer(int, QString, QString);

private:
    PedDevice *dev;
    QString _device;
    bool _FastScan;
    float _mb_hdsize;
    bool get_partfilesystem_info(PedPartition *, QP_PartInfo *);
    bool _partition_warn_busy(PedPartition *);
    QString _message;
    QP_PartInfo *_partActive;

signals:
    /*---emitted when there is need to update a progress bar---*/
    void sigTimer(int, QString, QString);
};

#endif
